==> igniteui-react-charts-16.4.1.tgz: package/ES2015/BollingerBandsOverlay_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { FinancialOverlay } from "./FinancialOverlay";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { Type, Number_$type, typeCast, runOn, markType, getEnumerator, Point_$type, fromEnum } from "igniteui-react-core/ES2015/type";
import { CategoryFrame } from "./CategoryFrame";
import { Series } from "./Series";
import { SafeEnumerable } from "./SafeEnumerable";
import { TrendCalculators } from "igniteui-react-core/ES2015/TrendCalculators";
import { AxisRange } from "./AxisRange";
import { FinancialSeriesView } from "./FinancialSeriesView";
import { ScalerParams } from "./ScalerParams";
import { ISortingAxis_$type } from "./ISortingAxis";
import { FinancialBucketCalculator } from "./FinancialBucketCalculator";
import { Polyline } from "igniteui-react-core/ES2015/Polyline";
import { Polygon } from "igniteui-react-core/ES2015/Polygon";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { isNaN_ } from "igniteui-react-core/ES2015/number";
import { Flattener } from "igniteui-react-core/ES2015/Flattener";
export class BollingerBandsOverlay extends FinancialOverlay {
    constructor() {
        super();
        this.ph = 0;
        this.pi = 0;
        this.pf = new List$1(Number_$type, 0);
        this.pg = new List$1(Number_$type, 0);
        this.ab = BollingerBandsOverlay.$;
        this.l2 = new CategoryFrame(4);
        this.l4 = new CategoryFrame(4);
        this.l1 = new CategoryFrame(4);
    }
    ir(a, b, c, d) {
        if (this.ni().contains(b)) {
            this.o9 = false;
        }
        super.ir(a, b, c, d);
        switch (b) {
            case BollingerBandsOverlay.$$p[1]:
                this.o9 = false;
                this.i4(false);
                break;
            case BollingerBandsOverlay.$$p[0]:
                this.i4(false);
                break;
        }
    }
    pa() {
        this.pf.clear();
        this.pg.clear();
        let a = getEnumerator(TrendCalculators.e(new SafeEnumerable(this.nh), this.pk));
        let b = getEnumerator(TrendCalculators.f(new SafeEnumerable(this.nh), this.pk));
        this.pi = 1.7976931348623157E+308;
        this.ph = -1.7976931348623157E+308;
        let c = true;
        let d = true;
        let e = this.pj;
        while (c || d) {
            if (a.moveNext()) {
                this.pf.add(a.current);
            }
            else {
                c = false;
            }
            if (b.moveNext()) {
                this.pg.add(b.current);
            }
            else {
                d = false;
            }
            if (c && d) {
                this.pi = Math.min(this.pi, a.current - b.current * e);
                this.ph = Math.max(this.ph, a.current + b.current * e);
            }
        }
        return true;
    }
    an(a) {
        if (this.pf == null || this.pg == null || a == null || this.bz == null || a != this.mk) {
            return null;
        }
        let b = new AxisRange(this.pi, this.ph);
        return b;
    }
    oq(a, b) {
        super.oq(a, b);
        let c = b.bq;
        let d = b.bp;
        let e = this.getEffectiveViewport1(b);
        let f = this.lz;
        let g = this.mk;
        let h = new ScalerParams(0, c, d, f.b8, e);
        let i = new ScalerParams(0, c, d, g.b8, e);
        a.f.clear();
        a.m.clear();
        a.p.clear();
        let j = typeCast(ISortingAxis_$type, this.lz);
        if (j != null && j.i$b.count != this.bz.count) {
            return;
        }
        let k = 0;
        k = this.nq(c, d, e);
        if (!this.o9) {
            this.o9 = this.pa();
            if (this.mk != null) {
                this.mk.cl(true);
            }
        }
        i.b = this.ed();
        let l = this.lz.dw(2, h) - this.lz.dw(1, h);
        for (let m = b.bs.c; m <= b.bs.d; ++m) {
            let n;
            if (j == null) {
                n = b.bs.getBucket(m);
            }
            else {
                let o = j.i$b._inner[m];
                let p = j.i$d(o);
                let q = this.pf._inner[m];
                let r = this.pg._inner[m];
                let s = q;
                let t = r;
                let u = p;
                let v = 1;
                while (m < b.bs.d) {
                    o = j.i$b._inner[m + 1];
                    u = j.i$d(o);
                    if (u - p > l) {
                        break;
                    }
                    m++;
                    s += this.pf._inner[m];
                    t += this.pg._inner[m];
                    v++;
                }
                s /= v;
                t /= v;
                let w = s - t * this.pj;
                let x = s;
                let y = s + t * this.pj;
                let z = NaN;
                if (!isNaN_(p)) {
                    z = this.lz.dt(p, h);
                }
                n = [z, w, x, y];
            }
            let aa = Math.max(1, l);
            if (!isNaN_(n[0]) && m * aa >= this.pb) {
                if (this.lz != null && typeCast(ISortingAxis_$type, this.lz) !== null) {
                    n[0] = n[0] + k;
                }
                else {
                    n[0] = f.dt(n[0], h) + k;
                }
                n[1] = g.dt(n[1], i);
                n[2] = g.dt(n[2], i);
                n[3] = g.dt(n[3], i);
                a.f.add(n);
            }
        }
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        if (c != null) {
            c.bz();
        }
    }
    ej(a, b, c) {
        if (this.pf == null) {
            return super.ej(a, b, c);
        }
        let d = this.getEffectiveViewport1(this.bi);
        let e = this.nq(this.bi.bq, this.bi.bp, d);
        let f = new ScalerParams(0, this.bi.bq, this.bi.bp, this.lz.b8, d);
        f.c = this.bs.my;
        return this.el(this.pf, a, this.lz, f, e, runOn(this, this.np), b, c);
    }
    fa(a, b) {
        if (this.pf == null) {
            return super.fa(a, b);
        }
        return this.fb(a, b, this.lz, runOn(this, this.np), this.pf);
    }
    e8(a, b) {
        if (this.pf == null) {
            return super.e8(a, b);
        }
        return this.e9(a, b, this.lz, runOn(this, this.np), this.pf);
    }
    du(a, b, c) {
        let d = super.du(a, b, c);
        if (!this.m8(this.ni())) {
            d = false;
        }
        return d;
    }
    os(a, b) {
        super.os(a, b);
        let c = typeCast(BollingerBandsOverlayView.$, b);
        let d = this.getEffectiveViewport1(b);
        if (b.bv(a)) {
            c.bz();
            let e = a.f.count;
            let f = (g) => a.f._inner[g][0];
            let g = (h) => a.f._inner[e - 1 - h][0];
            let h = (i) => a.f._inner[i][1];
            let i = (j) => a.f._inner[j][2];
            let j = (k) => a.f._inner[e - 1 - k][3];
            c.b0(e, f, g, h, i, j);
            b.bx(a);
        }
        this.l7.x(this, this.m7(), this.lz, runOn(this, this.lr), this.nw(b), this.ny(b));
        let k = false;
        let l = this.l7.c;
        let m = a.f;
        let n = this.bz.count;
        if (l != null) {
            k = true;
        }
        if (k) {
            let o = new ScalerParams(0, b.bq, b.bp, this.lz.b8, d);
            this.op(m, -1, n, this.lz, o, b.n);
        }
        let p = c.b7;
        let q = c.b8;
        let r = c.b9;
        let s = c.b2;
        this.l7.ae(q, true, false, true, true);
        this.l7.ao = null;
        this.l7.an = null;
        this.l7.ae(p, true, false, false, true);
        this.l7.ae(r, true, false, false, true);
        this.l7.ae(s, false, true, false, false);
        s._opacity = this.l7.i * this.d2;
    }
    bf() {
        return new BollingerBandsOverlayView(this);
    }
    il(a) {
        super.il(a);
        this.pe = typeCast(BollingerBandsOverlayView.$, a);
    }
    nz() {
        return 3;
    }
    ed() {
        return Series.ee(this.pf, null);
    }
}
BollingerBandsOverlay.$t = markType(BollingerBandsOverlay, 'BollingerBandsOverlay', FinancialOverlay.$);
Type.dep(DependencyProperty, PropertyMetadata, BollingerBandsOverlay, 'raisePropertyChanged', ['Multiplier:pj:pn', [1, 2], 'Period:pk:po', [1, 14]]);
export class BollingerBandsBucketCalculator extends FinancialBucketCalculator {
    constructor(a) {
        super(a);
        this.f = null;
        this.f = a;
    }
    getBucket(a) {
        let b = a * this.b;
        let c = Math.min(b + this.b - 1, this.a.bu.bz.count - 1);
        if (b <= c) {
            let d = this.f.by.pj;
            let e = 0;
            let f = 0;
            let g = 0;
            for (let h = b; h <= c; ++h) {
                if (!isNaN_(this.f.by.pf._inner[h]) && !isNaN_(this.f.by.pg._inner[h])) {
                    e += this.f.by.pf._inner[h];
                    f += this.f.by.pg._inner[h];
                    ++g;
                }
            }
            if (g > 0) {
                e = e / g;
                f = f / g;
                return [0.5 * (b + c), e - f * d, e, e + f * d];
            }
        }
        return [NaN, NaN, NaN, NaN];
    }
}
BollingerBandsBucketCalculator.$t = markType(BollingerBandsBucketCalculator, 'BollingerBandsBucketCalculator', FinancialBucketCalculator.$);
export class BollingerBandsOverlayView extends FinancialSeriesView {
    constructor(a) {
        super(a);
        this.by = null;
        this.b3 = new Polygon();
        this.ca = new Polyline();
        this.cb = new Polyline();
        this.cc = new Polyline();
        this.b1 = new Polygon();
        this.b4 = new Polyline();
        this.b5 = new Polyline();
        this.b6 = new Polyline();
        this.by = a;
    }
    ap() {
        super.ap();
        if (!this.n) {
            this.e.bj = 1;
        }
    }
    bt() {
        return new BollingerBandsBucketCalculator(this);
    }
    b0(a, b, c, d, e, f) {
        for (let g of fromEnum(Flattener.d(a, b, d, this.e.eq))) {
            this.b3.aj.add({ $type: Point_$type, x: b(g), y: d(g) });
            this.ca.aj.add({ $type: Point_$type, x: b(g), y: d(g) });
        }
        for (let h of fromEnum(Flattener.d(a, b, e, this.e.eq))) {
            this.cb.aj.add({ $type: Point_$type, x: b(h), y: e(h) });
        }
        for (let i of fromEnum(Flattener.d(a, c, f, this.e.eq))) {
            this.b3.aj.add({ $type: Point_$type, x: c(i), y: f(i) });
            this.cc.aj.add({ $type: Point_$type, x: c(i), y: f(i) });
        }
        this.an();
    }
    bz() {
        this.b3.aj.clear();
        this.ca.aj.clear();
        this.cb.aj.clear();
        this.cc.aj.clear();
        this.an();
    }
    get b2() {
        return this.b3;
    }
    get b7() {
        return this.ca;
    }
    get b8() {
        return this.cb;
    }
    get b9() {
        return this.cc;
    }
    a9() {
        super.a9();
        this.b1.aj = this.b3.aj;
        this.b4.aj = this.ca.aj;
        this.b5.aj = this.cb.aj;
        this.b6.aj = this.cc.aj;
        let a = this.bk();
        this.b1._fill = a;
        this.b1._opacity = 1;
        this.b4._stroke = a;
        this.b4.ac = this.e.eu + 3;
        this.b5._stroke = a;
        this.b5.ac = this.e.eu + 3;
        this.b6._stroke = a;
        this.b6.ac = this.e.eu + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            if (b) {
                a.t(this.b1);
                a.u(this.b4);
                a.u(this.b5);
                a.u(this.b6);
            }
            else {
                a.t(this.b3);
                a.u(this.ca);
                a.u(this.cb);
                a.u(this.cc);
            }
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPolygonData(a, this.b3, "FillShape", ["Fill"]);
        this.e.a2.exportPolylineData(a, this.ca, "BottomLine", ["Lower", "Main"]);
        this.e.a2.exportPolylineData(a, this.cb, "CentralLine", ["Central"]);
        this.e.a2.exportPolylineData(a, this.cc, "TopLine", ["Upper"]);
    }
}
BollingerBandsOverlayView.$t = markType(BollingerBandsOverlayView, 'BollingerBandsOverlayView', FinancialSeriesView.$);
/*<BeginStatics Name="Infragistics.Controls.Charts.BollingerBandsOverlay" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.BollingerBandsOverlay" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES2015/BollingerBandsOverlay_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { FinancialOverlay } from "./FinancialOverlay";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { Type, Number_$type, typeCast, runOn, markType, getEnumerator, Point_$type, fromEnum } from "igniteui-react-core/ES2015/type";
import { CategoryFrame } from "./CategoryFrame";
import { Series } from "./Series";
import { SafeEnumerable } from "./SafeEnumerable";
import { TrendCalculators } from "igniteui-react-core/ES2015/TrendCalculators";
import { AxisRange } from "./AxisRange";
import { FinancialSeriesView } from "./FinancialSeriesView";
import { ScalerParams } from "./ScalerParams";
import { ISortingAxis_$type } from "./ISortingAxis";
import { FinancialBucketCalculator } from "./FinancialBucketCalculator";
import { Polyline } from "igniteui-react-core/ES2015/Polyline";
import { Polygon } from "igniteui-react-core/ES2015/Polygon";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { isNaN_ } from "igniteui-react-core/ES2015/number";
import { Flattener } from "igniteui-react-core/ES2015/Flattener";
export class BollingerBandsOverlay extends FinancialOverlay {
    constructor() {
        super();
        this.ph = 0;
        this.pi = 0;
        this.pf = new List$1(Number_$type, 0);
        this.pg = new List$1(Number_$type, 0);
        this.ab = BollingerBandsOverlay.$;
        this.l2 = new CategoryFrame(4);
        this.l4 = new CategoryFrame(4);
        this.l1 = new CategoryFrame(4);
    }
    ir(a, b, c, d) {
        if (this.ni().contains(b)) {
            this.o9 = false;
        }
        super.ir(a, b, c, d);
        switch (b) {
            case BollingerBandsOverlay.$$p[1]:
                this.o9 = false;
                this.i4(false);
                break;
            case BollingerBandsOverlay.$$p[0]:
                this.i4(false);
                break;
        }
    }
    pa() {
        this.pf.clear();
        this.pg.clear();
        let a = getEnumerator(TrendCalculators.e(new SafeEnumerable(this.nh), this.pk));
        let b = getEnumerator(TrendCalculators.f(new SafeEnumerable(this.nh), this.pk));
        this.pi = 1.7976931348623157E+308;
        this.ph = -1.7976931348623157E+308;
        let c = true;
        let d = true;
        let e = this.pj;
        while (c || d) {
            if (a.moveNext()) {
                this.pf.add(a.current);
            }
            else {
                c = false;
            }
            if (b.moveNext()) {
                this.pg.add(b.current);
            }
            else {
                d = false;
            }
            if (c && d) {
                this.pi = Math.min(this.pi, a.current - b.current * e);
                this.ph = Math.max(this.ph, a.current + b.current * e);
            }
        }
        return true;
    }
    an(a) {
        if (this.pf == null || this.pg == null || a == null || this.bz == null || a != this.mk) {
            return null;
        }
        let b = new AxisRange(this.pi, this.ph);
        return b;
    }
    oq(a, b) {
        super.oq(a, b);
        let c = b.bs;
        let d = b.br;
        let e = this.getEffectiveViewport1(b);
        let f = this.lz;
        let g = this.mk;
        let h = new ScalerParams(0, c, d, f.b8, e);
        let i = new ScalerParams(0, c, d, g.b8, e);
        a.f.clear();
        a.m.clear();
        a.p.clear();
        let j = typeCast(ISortingAxis_$type, this.lz);
        if (j != null && j.i$b.count != this.bz.count) {
            return;
        }
        let k = 0;
        k = this.nq(c, d, e);
        if (!this.o9) {
            this.o9 = this.pa();
            if (this.mk != null) {
                this.mk.cl(true);
            }
        }
        i.b = this.ed();
        let l = this.lz.dw(2, h) - this.lz.dw(1, h);
        for (let m = b.bu.c; m <= b.bu.d; ++m) {
            let n;
            if (j == null) {
                n = b.bu.getBucket(m);
            }
            else {
                let o = j.i$b._inner[m];
                let p = j.i$d(o);
                let q = this.pf._inner[m];
                let r = this.pg._inner[m];
                let s = q;
                let t = r;
                let u = p;
                let v = 1;
                while (m < b.bu.d) {
                    o = j.i$b._inner[m + 1];
                    u = j.i$d(o);
                    if (u - p > l) {
                        break;
                    }
                    m++;
                    s += this.pf._inner[m];
                    t += this.pg._inner[m];
                    v++;
                }
                s /= v;
                t /= v;
                let w = s - t * this.pj;
                let x = s;
                let y = s + t * this.pj;
                let z = NaN;
                if (!isNaN_(p)) {
                    z = this.lz.dt(p, h);
                }
                n = [z, w, x, y];
            }
            let aa = Math.max(1, l);
            if (!isNaN_(n[0]) && m * aa >= this.pb) {
                if (this.lz != null && typeCast(ISortingAxis_$type, this.lz) !== null) {
                    n[0] = n[0] + k;
                }
                else {
                    n[0] = f.dt(n[0], h) + k;
                }
                n[1] = g.dt(n[1], i);
                n[2] = g.dt(n[2], i);
                n[3] = g.dt(n[3], i);
                a.f.add(n);
            }
        }
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        if (c != null) {
            c.b1();
        }
    }
    ej(a, b, c) {
        if (this.pf == null) {
            return super.ej(a, b, c);
        }
        let d = this.getEffectiveViewport1(this.bi);
        let e = this.nq(this.bi.bs, this.bi.br, d);
        let f = new ScalerParams(0, this.bi.bs, this.bi.br, this.lz.b8, d);
        f.c = this.bs.m0;
        return this.el(this.pf, a, this.lz, f, e, runOn(this, this.np), b, c);
    }
    fa(a, b) {
        if (this.pf == null) {
            return super.fa(a, b);
        }
        return this.fb(a, b, this.lz, runOn(this, this.np), this.pf);
    }
    e8(a, b) {
        if (this.pf == null) {
            return super.e8(a, b);
        }
        return this.e9(a, b, this.lz, runOn(this, this.np), this.pf);
    }
    du(a, b, c) {
        let d = super.du(a, b, c);
        if (!this.m8(this.ni())) {
            d = false;
        }
        return d;
    }
    os(a, b) {
        super.os(a, b);
        let c = typeCast(BollingerBandsOverlayView.$, b);
        let d = this.getEffectiveViewport1(b);
        if (b.bx(a)) {
            c.b1();
            let e = a.f.count;
            let f = (g) => a.f._inner[g][0];
            let g = (h) => a.f._inner[e - 1 - h][0];
            let h = (i) => a.f._inner[i][1];
            let i = (j) => a.f._inner[j][2];
            let j = (k) => a.f._inner[e - 1 - k][3];
            c.b2(e, f, g, h, i, j);
            b.bz(a);
        }
        this.l7.x(this, this.m7(), this.lz, runOn(this, this.lr), this.nw(b), this.ny(b));
        let k = false;
        let l = this.l7.c;
        let m = a.f;
        let n = this.bz.count;
        if (l != null) {
            k = true;
        }
        if (k) {
            let o = new ScalerParams(0, b.bs, b.br, this.lz.b8, d);
            this.op(m, -1, n, this.lz, o, b.n);
        }
        let p = c.b9;
        let q = c.ca;
        let r = c.cb;
        let s = c.b4;
        this.l7.ae(q, true, false, true, true);
        this.l7.ao = null;
        this.l7.an = null;
        this.l7.ae(p, true, false, false, true);
        this.l7.ae(r, true, false, false, true);
        this.l7.ae(s, false, true, false, false);
        s._opacity = this.l7.i * this.d2;
    }
    bf() {
        return new BollingerBandsOverlayView(this);
    }
    il(a) {
        super.il(a);
        this.pe = typeCast(BollingerBandsOverlayView.$, a);
    }
    nz() {
        return 3;
    }
    ed() {
        return Series.ee(this.pf, null);
    }
}
BollingerBandsOverlay.$t = markType(BollingerBandsOverlay, 'BollingerBandsOverlay', FinancialOverlay.$);
Type.dep(DependencyProperty, PropertyMetadata, BollingerBandsOverlay, 'raisePropertyChanged', ['Multiplier:pj:pn', [1, 2], 'Period:pk:po', [1, 14]]);
export class BollingerBandsBucketCalculator extends FinancialBucketCalculator {
    constructor(a) {
        super(a);
        this.f = null;
        this.f = a;
    }
    getBucket(a) {
        let b = a * this.b;
        let c = Math.min(b + this.b - 1, this.a.bw.bz.count - 1);
        if (b <= c) {
            let d = this.f.b0.pj;
            let e = 0;
            let f = 0;
            let g = 0;
            for (let h = b; h <= c; ++h) {
                if (!isNaN_(this.f.b0.pf._inner[h]) && !isNaN_(this.f.b0.pg._inner[h])) {
                    e += this.f.b0.pf._inner[h];
                    f += this.f.b0.pg._inner[h];
                    ++g;
                }
            }
            if (g > 0) {
                e = e / g;
                f = f / g;
                return [0.5 * (b + c), e - f * d, e, e + f * d];
            }
        }
        return [NaN, NaN, NaN, NaN];
    }
}
BollingerBandsBucketCalculator.$t = markType(BollingerBandsBucketCalculator, 'BollingerBandsBucketCalculator', FinancialBucketCalculator.$);
export class BollingerBandsOverlayView extends FinancialSeriesView {
    constructor(a) {
        super(a);
        this.b0 = null;
        this.b5 = new Polygon();
        this.cc = new Polyline();
        this.cd = new Polyline();
        this.ce = new Polyline();
        this.b3 = new Polygon();
        this.b6 = new Polyline();
        this.b7 = new Polyline();
        this.b8 = new Polyline();
        this.b0 = a;
    }
    ap() {
        super.ap();
        if (!this.n) {
            this.e.bj = 1;
        }
    }
    bv() {
        return new BollingerBandsBucketCalculator(this);
    }
    b2(a, b, c, d, e, f) {
        for (let g of fromEnum(Flattener.d(a, b, d, this.e.eq))) {
            this.b5.aj.add({ $type: Point_$type, x: b(g), y: d(g) });
            this.cc.aj.add({ $type: Point_$type, x: b(g), y: d(g) });
        }
        for (let h of fromEnum(Flattener.d(a, b, e, this.e.eq))) {
            this.cd.aj.add({ $type: Point_$type, x: b(h), y: e(h) });
        }
        for (let i of fromEnum(Flattener.d(a, c, f, this.e.eq))) {
            this.b5.aj.add({ $type: Point_$type, x: c(i), y: f(i) });
            this.ce.aj.add({ $type: Point_$type, x: c(i), y: f(i) });
        }
        this.an();
    }
    b1() {
        this.b5.aj.clear();
        this.cc.aj.clear();
        this.cd.aj.clear();
        this.ce.aj.clear();
        this.an();
    }
    get b4() {
        return this.b5;
    }
    get b9() {
        return this.cc;
    }
    get ca() {
        return this.cd;
    }
    get cb() {
        return this.ce;
    }
    a9() {
        super.a9();
        this.b3.aj = this.b5.aj;
        this.b6.aj = this.cc.aj;
        this.b7.aj = this.cd.aj;
        this.b8.aj = this.ce.aj;
        let a = this.bl();
        this.b3._fill = a;
        this.b3._opacity = 1;
        this.b6._stroke = a;
        this.b6.ac = this.e.eu + 3;
        this.b7._stroke = a;
        this.b7.ac = this.e.eu + 3;
        this.b8._stroke = a;
        this.b8.ac = this.e.eu + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            if (b) {
                a.t(this.b3);
                a.u(this.b6);
                a.u(this.b7);
                a.u(this.b8);
            }
            else {
                a.t(this.b5);
                a.u(this.cc);
                a.u(this.cd);
                a.u(this.ce);
            }
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPolygonData(a, this.b5, "FillShape", ["Fill"]);
        this.e.a2.exportPolylineData(a, this.cc, "BottomLine", ["Lower", "Main"]);
        this.e.a2.exportPolylineData(a, this.cd, "CentralLine", ["Central"]);
        this.e.a2.exportPolylineData(a, this.ce, "TopLine", ["Upper"]);
    }
}
BollingerBandsOverlayView.$t = markType(BollingerBandsOverlayView, 'BollingerBandsOverlayView', FinancialSeriesView.$);
